@@ -7,9 +7,9 @@ use alloc::{
 };
 
 #[cfg(windows)]
-pub const NL: &'static str = "\r\n";
+pub const NL: &str = "\r\n";
 #[cfg(not(windows))]
-pub const NL: &'static str = "\n";
+pub const NL: &str = "\n";
 
 /// The root type.
 #[derive(Eq, PartialEq)]
@@ -36,8 +36,8 @@ impl<R: repr::Repr> Dumper for NodeBase<R> {
         if !self.anchor().is_empty() {
             doc += &format!("&{} ", self.anchor());
         }
-        if !self.ty().is_empty() {
-            doc += &format!("!!{} ", self.ty());
+        if !self.tag().is_empty() {
+            doc += &format!("!!{} ", self.tag());
         }
         let ind = Self::ind(level);
         doc += &match self.yaml() {
@@ -122,8 +122,8 @@ impl<R: repr::Repr> Dumper for NodeBase<R> {
 ///
 /// let doc = dump(vec![
 ///     node!({
-///         node!("a") => node!("b"),
-///         node!("c") => node!("d"),
+///         "a" => "b",
+///         "c" => "d",
 ///     }),
 /// ]);
 /// assert_eq!(doc, format!("a: b{0}c: d{0}", NL));
